TfLiteXNNPackDelegateOptions class

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
flags int
Bitfield with any combination of the following binary options:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
num_threads int
Number of threads to use in the thread pool. 0 or negative value means no thread pool used.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weights_cache Pointer<TfLiteXNNPackDelegateWeightsCache>
Cache for packed weights, can be shared between multiple instances of delegates.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

allocate(int num_threads, int flags, Pointer<TfLiteXNNPackDelegateWeightsCache> weights_cache) Pointer<TfLiteXNNPackDelegateOptions>